# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingElectrocardiogramSourceType(str, enum.Enum):
    UNKNOWN = "unknown"
    PHONE = "phone"
    WATCH = "watch"
    APP = "app"
    MULTIPLE_SOURCES = "multiple_sources"
    FINGERPRICK = "fingerprick"
    CUFF = "cuff"
    MANUAL_SCAN = "manual_scan"
    AUTOMATIC = "automatic"
    SCALE = "scale"
    CHEST_STRAP = "chest_strap"
    RING = "ring"
    LAB = "lab"

    def visit(
        self,
        unknown: typing.Callable[[], T_Result],
        phone: typing.Callable[[], T_Result],
        watch: typing.Callable[[], T_Result],
        app: typing.Callable[[], T_Result],
        multiple_sources: typing.Callable[[], T_Result],
        fingerprick: typing.Callable[[], T_Result],
        cuff: typing.Callable[[], T_Result],
        manual_scan: typing.Callable[[], T_Result],
        automatic: typing.Callable[[], T_Result],
        scale: typing.Callable[[], T_Result],
        chest_strap: typing.Callable[[], T_Result],
        ring: typing.Callable[[], T_Result],
        lab: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingElectrocardiogramSourceType.UNKNOWN:
            return unknown()
        if self is ClientFacingElectrocardiogramSourceType.PHONE:
            return phone()
        if self is ClientFacingElectrocardiogramSourceType.WATCH:
            return watch()
        if self is ClientFacingElectrocardiogramSourceType.APP:
            return app()
        if self is ClientFacingElectrocardiogramSourceType.MULTIPLE_SOURCES:
            return multiple_sources()
        if self is ClientFacingElectrocardiogramSourceType.FINGERPRICK:
            return fingerprick()
        if self is ClientFacingElectrocardiogramSourceType.CUFF:
            return cuff()
        if self is ClientFacingElectrocardiogramSourceType.MANUAL_SCAN:
            return manual_scan()
        if self is ClientFacingElectrocardiogramSourceType.AUTOMATIC:
            return automatic()
        if self is ClientFacingElectrocardiogramSourceType.SCALE:
            return scale()
        if self is ClientFacingElectrocardiogramSourceType.CHEST_STRAP:
            return chest_strap()
        if self is ClientFacingElectrocardiogramSourceType.RING:
            return ring()
        if self is ClientFacingElectrocardiogramSourceType.LAB:
            return lab()
