# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingBloodPressureChangedEventType(str, enum.Enum):
    DAILY_DATA_BLOOD_PRESSURE_CREATED = "daily.data.blood_pressure.created"
    DAILY_DATA_BLOOD_PRESSURE_UPDATED = "daily.data.blood_pressure.updated"

    def visit(
        self,
        daily_data_blood_pressure_created: typing.Callable[[], T_Result],
        daily_data_blood_pressure_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingBloodPressureChangedEventType.DAILY_DATA_BLOOD_PRESSURE_CREATED:
            return daily_data_blood_pressure_created()
        if self is ClientFacingBloodPressureChangedEventType.DAILY_DATA_BLOOD_PRESSURE_UPDATED:
            return daily_data_blood_pressure_updated()
